import { JSON_HEADERS } from './headers';

export class ValidationError extends Error {
  constructor(message, code, param) {
    super(message);
    this.code = code;
    this.param = param;
    this.type = 'invalid_request_error';
  }
}

export const errorHandler = (error) => {
  const status = error instanceof ValidationError ? 400 
    : error.code === 'invalid_api_key' ? 401 
    : 500;

  return Response.json({
    error: {
      message: error.message,
      type: error.type || 'api_error',
      code: error.code || 'internal_error',
      param: error.param,
      metadata: {
        timestamp: new Date().toISOString(),
        request_id: crypto.randomUUID()
      }
    }
  }, { 
    status,
    headers: JSON_HEADERS
  });
};
