export const formatters = {
  toCloudflare: (params, type) => {
    // 从参数中提取所有可能的字段
    const {
      stream = false,
      max_tokens,
      temperature,
      top_p,
      top_k,
      seed,
      repetition_penalty,
      frequency_penalty,
      presence_penalty,
      raw,
      lora,
      functions,
      tools,
      messages,
      prompt
    } = params;

    // 构建基础请求参数
    const requestParams = {
      messages: type === 'prompt' 
        ? [{ role: "user", content: prompt }] 
        : messages,
      stream
    };

    // 添加各种可选参数，只在有值时添加
    const optionalParams = {
      max_tokens,
      temperature,
      top_p,
      top_k,
      seed,
      repetition_penalty,
      frequency_penalty,
      presence_penalty,
      raw,
      lora
    };

    // 添加函数调用相关参数
    if (functions?.length) {
      requestParams.functions = functions;
    }
    if (tools?.length) {
      requestParams.tools = tools;
    }

    // 过滤掉未定义的可选参数
    Object.entries(optionalParams).forEach(([key, value]) => {
      if (value !== undefined) {
        requestParams[key] = value;
      }
    });

    return requestParams;
  },

  toOpenAI: (response, type, model, isStream = false) => {
    const content = typeof response === 'string' ? response : response.response || '';
    const id = `${type === 'chat' ? 'chatcmpl' : 'cmpl'}-${crypto.randomUUID()}`;
    const timestamp = Date.now();

    const baseResponse = {
      id,
      created: timestamp,
      model,
      choices: [{
        index: 0,
        finish_reason: isStream ? null : "stop"
      }]
    };

    if (isStream) {
      baseResponse.object = `${type}.completion.chunk`;
      baseResponse.choices[0][type === 'chat' ? 'delta' : 'text'] = 
        type === 'chat' ? { role: 'assistant', content } : content;
    } else {
      baseResponse.object = `${type}.completion`;
      baseResponse.choices[0][type === 'chat' ? 'message' : 'text'] = 
        type === 'chat' ? { role: 'assistant', content } : content;
      baseResponse.usage = { prompt_tokens: -1, completion_tokens: -1, total_tokens: -1 };
    }

    return baseResponse;
  }
};
