import { formatters } from './formatters';

export const createStreamHandler = (type, model) => {
  const encoder = new TextEncoder();
  const decoder = new TextDecoder();

  return new TransformStream({
    transform(chunk, controller) {
      const text = decoder.decode(chunk);
      if (!text.trim()) return;

      const lines = text.split("\n").filter(line => line.trim());
      
      for (const line of lines) {
        if (line.includes('[DONE]')) {
          const finalResponse = formatters.toOpenAI('', type, model, true);
          finalResponse.choices[0].finish_reason = 'stop';
          controller.enqueue(encoder.encode(
            `data: ${JSON.stringify(finalResponse)}\n\ndata: [DONE]\n\n`
          ));
          return;
        }

        if (line.startsWith('data: ')) {
          try {
            const rawResponse = JSON.parse(line.slice(6));
            if (rawResponse?.response !== undefined) {
              const formatted = formatters.toOpenAI(rawResponse.response, type, model, true);
              controller.enqueue(encoder.encode(`data: ${JSON.stringify(formatted)}\n\n`));
            }
          } catch (e) {
            console.error('Stream parse error:', e, 'for line:', line);
          }
        }
      }
    }
  });
};
